@@ -93,18 +93,22 @@ class TestWSGIHandler(TestCase):
         self.assertEqual("for testing purposes", response.error.message)
 
     def test_handle_request_runtime_error(self) -> None:
-        stream: StringIO = StringIO()
-        request: EnvironBuilder = EnvironBuilder(method="POST", errors_stream=stream, json={"jsonrpc": "2.0", "method": "print"})
+        with StringIO() as raw_buffer:
+            request: EnvironBuilder = EnvironBuilder(
+                method="POST",
+                errors_stream=raw_buffer,
+                json={"jsonrpc": "2.0", "method": "print"},
+            )
 
-        with patch.object(WSGIHandler, "_read_request_body") as mock:
-            mock.side_effect = RuntimeError("for testing purposes")
+            with patch.object(WSGIHandler, "_read_request_body") as mock:
+                mock.side_effect = RuntimeError("for testing purposes")
 
-            with self.assertRaises(RuntimeError) as context:
-                self.client.open(request)
+                with self.assertRaises(RuntimeError) as context:
+                    self.client.open(request)
 
-        self.assertIsInstance(context.exception, RuntimeError)
-        self.assertEqual(str(context.exception), "for testing purposes")
-        self.assertIn("RuntimeError: for testing purposes", stream.getvalue())
+            self.assertIsInstance(context.exception, RuntimeError)
+            self.assertEqual(str(context.exception), "for testing purposes")
+            self.assertIn("RuntimeError: for testing purposes", raw_buffer.getvalue())
 
     def test_forbidden_methods(self) -> None:
         responses: tuple[TestResponse, ...] = (
@@ -171,32 +175,47 @@ class TestWSGIHandler(TestCase):
         self.assertIn("hello world", self.collection)
 
     def test_large_request_body(self) -> None:
-        self.assertNotIn(payload := urandom(150 * 1024 * 1024).hex(), self.collection)
+        for payload in (
+            payload0 := urandom(50 * 1024 * 1024).hex(),
+            payload1 := urandom(50 * 1024 * 1024).hex(),
+            payload2 := urandom(50 * 1024 * 1024).hex(),
+        ):
+            with self.subTest(payload=payload):
+                self.assertNotIn(payload, self.collection)
 
-        response: TestResponse = self.client.put(json={"jsonrpc": "2.0", "method": "append", "params": [payload]})
+        response: TestResponse = self.client.put(
+            json=[
+                {"jsonrpc": "2.0", "method": "append", "params": [payload0]},
+                {"jsonrpc": "2.0", "method": "append", "params": [payload1]},
+                {"jsonrpc": "2.0", "method": "append", "params": [payload2]},
+            ]
+        )
         self.assertEqual(response.status_code, HTTPStatus.NO_CONTENT)
         self.assertEqual(response.data, b"")
-        self.assertIn(payload, self.collection)
+
+        for payload in (payload0, payload1, payload2):
+            with self.subTest(payload=payload):
+                self.assertIn(payload, self.collection)
 
     def test_unexpected_client_disconnected(self) -> None:
-        stream: StringIO = StringIO()
-        request: EnvironBuilder = EnvironBuilder(
-            method="PUT",
-            errors_stream=stream,
-            environ_overrides={"CONTENT_LENGTH": "1000"},
-            json={
-                "jsonrpc": "2.0",
-                "method": "append",
-                "params": ["Unexpected client disconnected"],
-            },
-        )
+        with StringIO() as raw_buffer:
+            request: EnvironBuilder = EnvironBuilder(
+                method="PUT",
+                errors_stream=raw_buffer,
+                environ_overrides={"CONTENT_LENGTH": "1000"},
+                json={
+                    "jsonrpc": "2.0",
+                    "method": "append",
+                    "params": ["Unexpected client disconnected"],
+                },
+            )
 
-        with self.assertRaises(EOFError) as context:
-            self.client.open(request)
+            with self.assertRaises(EOFError) as context:
+                self.client.open(request)
 
-        self.assertNotIn("Unexpected client disconnected", self.collection)
-        self.assertIn("Client disconnected", str(context.exception))
-        self.assertIn("more bytes were expected", stream.getvalue())
+            self.assertNotIn("Unexpected client disconnected", self.collection)
+            self.assertIn("Client disconnected", str(context.exception))
+            self.assertIn("more bytes were expected", raw_buffer.getvalue())
 
     def test_non_existent_method(self) -> None:
         uuid: str = self.random_id
